@@ -16,6 +16,21 @@ module Sass
             super('display-p3', Utils::RGB_CHANNELS)
           end
 
+          def convert(dest, red, green, blue, alpha)
+            if dest == DISPLAY_P3_LINEAR
+              Color.send(
+                :for_space_internal,
+                dest,
+                red.nil? ? nil : to_linear(red),
+                green.nil? ? nil : to_linear(green),
+                blue.nil? ? nil : to_linear(blue),
+                alpha
+              )
+            else
+              convert_linear(dest, red, green, blue, alpha)
+            end
+          end
+
           def to_linear(channel)
             Utils.srgb_and_display_p3_to_linear(channel)
           end
